powered by
Supports both static page urls and their equivalent API calls.
wt_wiki_page(url, ...)
an HttpResponse response object from crul
HttpResponse
(character) MediaWiki page url.
Arguments passed to wt_wiki_url_build() if url is a static page url.
wt_wiki_url_build()
url
If the URL given is for a human readable html page, we convert it to equivalent API call - if URL is already an API call, we just use that.
Other MediaWiki functions: wt_wiki_page_parse(), wt_wiki_url_build(), wt_wiki_url_parse()
wt_wiki_page_parse()
wt_wiki_url_parse()
if (FALSE) { wt_wiki_page("https://en.wikipedia.org/wiki/Malus_domestica") }
Run the code above in your browser using DataLab