Learn R Programming

wikitaxa (version 0.4.0)

wt_wiki_page: Get MediaWiki Page from API

Description

Supports both static page urls and their equivalent API calls.

Usage

wt_wiki_page(url, ...)

Arguments

url

(character) MediaWiki page url.

...

Arguments passed to wt_wiki_url_build() if url is a static page url.

Value

an HttpResponse response object from crul

Details

If the URL given is for a human readable html page, we convert it to equivalent API call - if URL is already an API call, we just use that.

See Also

Other MediaWiki functions: wt_wiki_page_parse(), wt_wiki_url_build(), wt_wiki_url_parse()

Examples

Run this code
# NOT RUN {
wt_wiki_page("https://en.wikipedia.org/wiki/Malus_domestica")
# }

Run the code above in your browser using DataLab